# tinder

[![Build Status](https://travis-ci.org/elbaro/tinder.svg?branch=master)](https://travis-ci.org/elbaro/tinder)

[![Docs Link](https://img.shields.io/badge/docs-master-orange.svg)](https://elbaro.github.io/tinder)

Pytorch library.

See ![Documentation](https://elbaro.github.io/tinder)

## Usage

```
pip install tinder
```

```py
import tinder
```

